@@ -17,7 +17,8 @@
 #
 
 NAME = "ginvoke"
-VERSION = tuple([int(x) for x in "0.4.4".split(".")])
+VERSION = tuple([int(x) for x in "0.4.5".split(".")])
 
-from .bootstrap import run
+import gtk
+from .ui.app import run
 
