@@ -17,7 +17,6 @@
 #
 
 import gobject
-import gtk
 import re
 
 from .actions import wildcard
@@ -30,15 +29,15 @@ class Commands(gobject.GObject):
 
     def reset(self):
         self._reset()
-        self.emit("reset")
+        self.emit("reset-commands")
 
     def add(self, command, handler, *params):
         self.commands[command] = (handler, params)
-        self.emit("add", command)
+        self.emit("add-command", command)
 
     def alias(self, command, alias):
         self.commands[alias] = self.commands[command]
-        self.emit("add", alias)
+        self.emit("add-command", alias)
 
     def setwildcard(self, handler, *params):
         self.wildcard = (handler, params)
@@ -58,6 +57,6 @@ class Commands(gobject.GObject):
         self.commands = {}
         self.wildcard = (wildcard, tuple())
 
-gobject.signal_new("add", Commands, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [str])
-gobject.signal_new("reset", Commands, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [])
+gobject.signal_new("add-command", Commands, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [str])
+gobject.signal_new("reset-commands", Commands, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [])
 
