@@ -3,7 +3,7 @@ import gtk
 import os
 
 ICON_SEARCH_PATH = [
-    os.path.join("/usr/local/share/pixmaps", "ginvoke.png"),
+    os.path.join("/usr/share/pixmaps", "ginvoke.png"),
     os.path.join(
         os.path.dirname(__file__), '..', 'data', 'pixmaps', 'ginvoke.png')
 ]
